<?php

namespace Drupal\mandatly_cookie_compliance\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Mandatly Settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Mandatly form settings.
   */
  public function getFormId() {
    return 'mandatly_cookie_compliance_settings';
  }

  /**
   * Mandatly cookie compliance settings.
   */
  protected function getEditableConfigNames() {
    return ['mandatly_cookie_compliance.settings'];
  }

  /**
   * Form for cookie compliance.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mandatly_cookie_compliance.settings');

    $form['#prefix'] = '<div class="global">';
    $form['#suffix'] = '</div>';

    $form['show_banner'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('<span class="showbanner">Show Banner</span>'),
      '#default_value' => $config->get('show_banner') ?? 1,
      '#prefix' => '<div class="show"><span class="toggle-switch">',
      '#suffix' => '</span></div>',
      '#ajax' => [
        'callback' => '::refreshDynamicFields',
        'wrapper' => 'dynamic-wrapper',
        'event' => 'change',
        'progress' => ['type' => 'none'],
      ],
    ];

    $form['demo_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('<span class="demomode">Demo Mode</span>'),
      '#default_value' => $config->get('demo_mode') ?? 1,
      '#prefix' => '<div class="DemO"><span class="toggle-switch">',
      '#suffix' => '</span></div>',
      '#ajax' => [
        'callback' => '::refreshDynamicFields',
        'wrapper' => 'dynamic-wrapper',
        'event' => 'change',
        'progress' => ['type' => 'none'],
      ],
    ];

    $form['dynamic_section'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'dynamic-wrapper'],
    ];

    $show_banner = $form_state->getValue('show_banner', $config->get('show_banner'));
    $demo_mode = $form_state->getValue('demo_mode', $config->get('demo_mode'));
    $config->save(TRUE);

    \Drupal::service('router.builder')->rebuild();
    \Drupal::cache()->invalidateAll();
    \Drupal::service('cache_tags.invalidator')->invalidateTags(['config:mandatly_cookie_compliance.settings']);

    if ($demo_mode) {
      $form['dynamic_section']['demo_text'] = [
        '#type' => 'item',
        '#markup' => '<div class="demo">Demo mode is currently active and displays a dummy banner on your website. To implement actual banner, you can turn off demo mode.</div>',
      ];

    }
    if (!$demo_mode) {
      $form['dynamic_section']['website_guid'] = [
        '#type' => 'textfield',
        '#title' => 'Website GUID',
        '#placeholder' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx',
        '#default_value' => $config->get('website_guid'),
        '#required' => TRUE,
      ];

      $home_url = "../../../";
      $form['dynamic_section']['preview_banner'] = [
        '#type' => 'markup',
        '#markup' => '<div class="preview"><a href="' . $home_url . '" target="_blank">Preview Banner</a></div>',
      ];
      $form['dynamic_section']['guid_help'] = [
        '#type' => 'markup',
        '#markup' => '<div class="guid"><a href="https://help.mandatly.net/HowtogetWebsiteGUID" target="_blank">How to get GUID?</a></div>',
      ];

    }
    $form['signup_info'] = [
      '#type' => 'markup',
      '#markup' => '<div class="signup">You need a Mandatly account to implement the cookie banner using this plugin. Don\'t have an account?  <a href="https://mandatly.com/signup?sc=QS1DQy1CUy1HTA%3D%3D" target="_blank">Free sign up now</a></div>',
    ];

    /* Add your banner markup.*/
    $form['banner'] = [
      '#markup' => '<div id="cookie-banner-container"></div>',
      '#attached' => [
        'library' => [
          'mandatly_cookie_compliance/cookie_banner',
        ],
      ],
    ];
    $form = parent::buildForm($form, $form_state);
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#attributes' => ['class' => ['save']],
      '#states' => [
        'invisible' => [
          ':input[name="demo_mode"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['actions']['submit']['#attributes']['class'][] = 'save';

    return $form;
  }

  /**
   * Function for refresh dynamic fields.
   */
  public function refreshDynamicFields(array &$form, FormStateInterface $form_state) {
    $show_banner = $form_state->getValue('show_banner');

    /* Save the config.*/
    $this->config('mandatly_cookie_compliance.settings')
      ->set('show_banner', $show_banner)
      ->save();

    $demo_mode = $form_state->getValue('demo_mode');

    /* Save the config.*/
    $this->config('mandatly_cookie_compliance.settings')
      ->set('demo_mode', $demo_mode)
      ->save();
    $form_state->setRebuild(TRUE);
    return $form['dynamic_section'];
  }

  /**
   * Mandatly Cookie compliance Settings.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('mandatly_cookie_compliance.settings');
    $show_banner = $form_state->getValue('show_banner', $config->get('show_banner'));
    $demo_mode = $form_state->getValue('demo_mode', $config->get('demo_mode'));

    if ($show_banner && !$demo_mode) {
      $config->set('website_guid', $form_state->getValue('website_guid'));
    }
    else {
      $config->clear('website_guid');
    }
    $config->save(TRUE);

    \Drupal::service('router.builder')->rebuild();
    \Drupal::cache()->invalidateAll();
    \Drupal::service('cache_tags.invalidator')->invalidateTags(['config:mandatly_cookie_compliance.settings']);

    parent::submitForm($form, $form_state);
  }

}
